@@ -40,3 +40,30 @@ except ImportError: # pragma: no cover
     from django.contrib.auth.models import User
     User.USERNAME_FIELD = 'username'
     get_user_model = lambda: User
+
+
+# urllib
+try:
+    from urllib.parse import urlencode, parse_qs, urlparse
+except ImportError: # pragma: no cover
+    # Python 2.X
+    from urllib import urlencode
+    from urlparse import parse_qs, urlparse
+
+
+try:
+    from django.utils.encoding import force_text, smart_bytes, force_bytes
+except ImportError: # pragma: no cover
+    from django.utils.encoding import force_unicode as force_text
+    from django.utils.encoding import smart_str as smart_bytes
+    try:
+        from django.utils.encoding import force_str as force_bytes
+    except ImportError:
+        # This didn't get back-ported to 1.4.X
+        force_bytes = smart_bytes
+
+# Vendored six
+try:
+    from django.utils import six
+except:
+    from requests.packages.urllib3.packages import six
\ No newline at end of file
