@@ -13,6 +13,7 @@ from django.shortcuts import redirect
 from django.views.generic import RedirectView, View
 
 from .clients import get_client
+from .compat import smart_bytes, force_text
 from .compat import get_user_model
 from .models import Provider, AccountAccess
 
@@ -20,10 +21,22 @@ from .models import Provider, AccountAccess
 logger = logging.getLogger('allaccess.views')
 
 
-class OAuthRedirect(RedirectView):
+class OAuthClientMixin(object):
+    "Mixin for getting OAuth client for a provider."
+
+    client_class = None
+
+    def get_client(self, provider):
+        "Get instance of the OAuth client for this provider."
+        if self.client_class is not None:
+            return self.client_class(provider)
+        return get_client(provider)
+
+
+class OAuthRedirect(OAuthClientMixin, RedirectView):
     "Redirect user to OAuth provider to enable access."
 
-    permanent = False  
+    permanent = False
 
     def get_additional_parameters(self, provider):
         "Return additional redirect parameters for this provider."
@@ -32,7 +45,7 @@ class OAuthRedirect(RedirectView):
     def get_callback_url(self, provider):
         "Return the callback url for this provider."
         return reverse('allaccess-callback', kwargs={'provider': provider.name})
-        
+
     def get_redirect_url(self, **kwargs):
         "Build redirect url for a given provider."
         name = kwargs.get('provider', '')
@@ -41,15 +54,15 @@ class OAuthRedirect(RedirectView):
         except Provider.DoesNotExist:
             raise Http404('Unknown OAuth provider.')
         else:
-            client = get_client(provider)
+            client = self.get_client(provider)
             callback = self.get_callback_url(provider)
             params = self.get_additional_parameters(provider)
             return client.get_redirect_url(self.request, callback=callback, parameters=params)
 
 
-class OAuthCallback(View):
+class OAuthCallback(OAuthClientMixin, View):
     "Base OAuth callback view."
-        
+
     def get(self, request, *args, **kwargs):
         name = kwargs.get('provider', '')
         try:
@@ -57,7 +70,7 @@ class OAuthCallback(View):
         except Provider.DoesNotExist:
             raise Http404('Unknown OAuth provider.')
         else:
-            client = get_client(provider)
+            client = self.get_client(provider)
             callback = self.get_callback_url(provider)
             # Fetch access token
             raw_token = client.get_access_token(self.request, callback=callback)
@@ -100,10 +113,10 @@ class OAuthCallback(View):
 
     def get_or_create_user(self, provider, access, info):
         "Create a shell auth.User."
-        digest = hashlib.sha1(str(access)).digest()
+        digest = hashlib.sha1(smart_bytes(access)).digest()
         # Base 64 encode to get below 30 characters
         # Removed padding characters
-        username = base64.urlsafe_b64encode(digest).replace('=', '')
+        username = force_text(base64.urlsafe_b64encode(digest)).replace('=', '')
         User = get_user_model()
         kwargs = {
             User.USERNAME_FIELD: username,
